@@ -29,7 +29,7 @@ def html_output(script_url, code):
 
 
 def gist_url(gist_id, filename=None):
-    url = "https://raw.github.com/gist/{}".format(gist_id)
+    url = "https://gist.github.com/raw/{}".format(gist_id)
     if filename is not None:
         url += "/{}".format(filename)
     return url
